#line 1 "Gmsh.yy.cpp"

#line 3 "Gmsh.yy.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer gmsh_yy_create_buffer
#define yy_delete_buffer gmsh_yy_delete_buffer
#define yy_scan_buffer gmsh_yy_scan_buffer
#define yy_scan_string gmsh_yy_scan_string
#define yy_scan_bytes gmsh_yy_scan_bytes
#define yy_init_buffer gmsh_yy_init_buffer
#define yy_flush_buffer gmsh_yy_flush_buffer
#define yy_load_buffer_state gmsh_yy_load_buffer_state
#define yy_switch_to_buffer gmsh_yy_switch_to_buffer
#define yypush_buffer_state gmsh_yypush_buffer_state
#define yypop_buffer_state gmsh_yypop_buffer_state
#define yyensure_buffer_stack gmsh_yyensure_buffer_stack
#define yy_flex_debug gmsh_yy_flex_debug
#define yyin gmsh_yyin
#define yyleng gmsh_yyleng
#define yylex gmsh_yylex
#define yylineno gmsh_yylineno
#define yyout gmsh_yyout
#define yyrestart gmsh_yyrestart
#define yytext gmsh_yytext
#define yywrap gmsh_yywrap
#define yyalloc gmsh_yyalloc
#define yyrealloc gmsh_yyrealloc
#define yyfree gmsh_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define gmsh_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer gmsh_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define gmsh_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer gmsh_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define gmsh_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer gmsh_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define gmsh_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string gmsh_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define gmsh_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes gmsh_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define gmsh_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer gmsh_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define gmsh_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer gmsh_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define gmsh_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state gmsh_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define gmsh_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer gmsh_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define gmsh_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state gmsh_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define gmsh_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state gmsh_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define gmsh_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack gmsh_yyensure_buffer_stack
#endif

#ifdef yylex
#define gmsh_yylex_ALREADY_DEFINED
#else
#define yylex gmsh_yylex
#endif

#ifdef yyrestart
#define gmsh_yyrestart_ALREADY_DEFINED
#else
#define yyrestart gmsh_yyrestart
#endif

#ifdef yylex_init
#define gmsh_yylex_init_ALREADY_DEFINED
#else
#define yylex_init gmsh_yylex_init
#endif

#ifdef yylex_init_extra
#define gmsh_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra gmsh_yylex_init_extra
#endif

#ifdef yylex_destroy
#define gmsh_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy gmsh_yylex_destroy
#endif

#ifdef yyget_debug
#define gmsh_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug gmsh_yyget_debug
#endif

#ifdef yyset_debug
#define gmsh_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug gmsh_yyset_debug
#endif

#ifdef yyget_extra
#define gmsh_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra gmsh_yyget_extra
#endif

#ifdef yyset_extra
#define gmsh_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra gmsh_yyset_extra
#endif

#ifdef yyget_in
#define gmsh_yyget_in_ALREADY_DEFINED
#else
#define yyget_in gmsh_yyget_in
#endif

#ifdef yyset_in
#define gmsh_yyset_in_ALREADY_DEFINED
#else
#define yyset_in gmsh_yyset_in
#endif

#ifdef yyget_out
#define gmsh_yyget_out_ALREADY_DEFINED
#else
#define yyget_out gmsh_yyget_out
#endif

#ifdef yyset_out
#define gmsh_yyset_out_ALREADY_DEFINED
#else
#define yyset_out gmsh_yyset_out
#endif

#ifdef yyget_leng
#define gmsh_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng gmsh_yyget_leng
#endif

#ifdef yyget_text
#define gmsh_yyget_text_ALREADY_DEFINED
#else
#define yyget_text gmsh_yyget_text
#endif

#ifdef yyget_lineno
#define gmsh_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno gmsh_yyget_lineno
#endif

#ifdef yyset_lineno
#define gmsh_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno gmsh_yyset_lineno
#endif

#ifdef yywrap
#define gmsh_yywrap_ALREADY_DEFINED
#else
#define yywrap gmsh_yywrap
#endif

#ifdef yyalloc
#define gmsh_yyalloc_ALREADY_DEFINED
#else
#define yyalloc gmsh_yyalloc
#endif

#ifdef yyrealloc
#define gmsh_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc gmsh_yyrealloc
#endif

#ifdef yyfree
#define gmsh_yyfree_ALREADY_DEFINED
#else
#define yyfree gmsh_yyfree
#endif

#ifdef yytext
#define gmsh_yytext_ALREADY_DEFINED
#else
#define yytext gmsh_yytext
#endif

#ifdef yyleng
#define gmsh_yyleng_ALREADY_DEFINED
#else
#define yyleng gmsh_yyleng
#endif

#ifdef yyin
#define gmsh_yyin_ALREADY_DEFINED
#else
#define yyin gmsh_yyin
#endif

#ifdef yyout
#define gmsh_yyout_ALREADY_DEFINED
#else
#define yyout gmsh_yyout
#endif

#ifdef yy_flex_debug
#define gmsh_yy_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug gmsh_yy_flex_debug
#endif

#ifdef yylineno
#define gmsh_yylineno_ALREADY_DEFINED
#else
#define yylineno gmsh_yylineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, yy_size_t len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 281
#define YY_END_OF_BUFFER 282
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1462] =
    {   0,
        0,    0,  282,  280,    1,    1,  280,    5,  280,    6,
      280,  280,  280,  280,  280,  275,   22,    2,  280,   17,
      280,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  280,   30,   26,   20,   27,
       18,   28,   19,    0,  277,    3,    4,   21,  276,  275,
        0,   24,   34,   31,   29,   32,   33,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,

      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  147,  148,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  187,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  250,  251,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,   25,   23,    0,  276,    0,    0,  278,  279,   36,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,   54,  279,  279,  279,  279,  279,

      279,  279,  279,  279,  279,  279,  279,  279,  279,   85,
       87,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  117,  279,
      279,  279,  279,  279,  279,  279,  279,  127,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  158,  279,  279,  279,
      279,  279,  168,  279,  279,  173,  279,  175,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  213,  279,  279,  279,  279,  279,  225,

      279,  279,  279,  279,  279,  279,  279,  235,  279,  279,
      279,  279,  253,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,    0,  277,    0,    0,  276,  279,  279,   38,  279,
      279,  279,  279,  279,  279,  279,   48,   49,  279,  279,
      279,  279,  279,  279,   66,  279,  279,   69,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,   82,
      279,  279,   86,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  103,  104,  279,  109,  279,  279,  279,
      279,  279,  116,  279,  119,  279,  279,  279,  123,  279,

      279,  126,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  142,  143,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  155,  156,  279,  279,  279,  279,  279,
      166,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      196,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  224,  226,  279,  279,  279,  279,  279,
      233,  234,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  252,  254,  279,  279,  279,  279,  279,

      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  274,   10,   16,    9,    8,  279,   13,   15,    0,
      276,   35,  279,  279,  279,   41,  279,  279,  279,  279,
       50,  279,   52,  279,   55,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,   78,  279,  279,
      279,  279,  279,  279,   93,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  112,  113,  279,  279,  279,
      120,  279,  279,  279,  125,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  145,  279,  279,  150,
      279,  279,  279,  279,  279,  159,  279,  279,  279,  279,

      165,  279,  279,  279,  279,  279,  279,  279,  279,  179,
      279,  182,  279,  279,  279,  279,  188,  279,  190,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  211,  212,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  227,  279,  279,  279,  231,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  259,  260,
      279,  279,  279,  279,  279,  279,  270,  279,  279,  273,
       12,   11,  279,   14,  279,  279,   40,  279,   44,   43,
       45,   46,  279,   53,  279,  279,  279,  279,  279,  279,

      279,   73,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,   99,  100,  279,  279,
      279,  279,  110,  111,  279,  115,  279,  279,  122,  279,
      279,  279,  279,  279,  133,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  151,  152,  279,  279,  279,  279,
      279,  279,  279,  279,  169,  279,  279,  174,  279,  279,
      279,  279,  279,  184,  279,  279,  189,  279,  192,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  207,  279,
      210,  279,  279,  279,  279,  279,  279,  279,  217,  222,
      279,  279,  229,  230,  279,  236,  279,  238,  279,  240,

      279,  279,  279,  244,  279,  246,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  267,  279,  279,
      271,  279,    7,  279,  279,  279,   47,   51,  279,  279,
      279,  279,  279,   71,  279,  279,  279,  279,  279,  279,
       80,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  102,  105,  279,  279,  279,  279,  118,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  193,  279,  279,  279,

      279,  279,  279,  279,  279,  209,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  232,  279,  239,  279,  279,
      279,  279,  247,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  272,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,   67,  279,
      279,  279,  279,   75,  279,  279,  279,   81,  279,  279,
      279,  279,  279,  279,   94,  279,  279,  279,  279,  279,
      106,  279,  108,  279,  279,  279,  128,  279,  279,  279,
      279,  279,  279,  279,  139,  279,  279,  144,  279,  279,
      153,  154,  279,  160,  279,  163,  164,  279,  279,  171,

      279,  279,  178,  279,  279,  279,  185,  186,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  228,  279,
      279,  279,  279,  279,  248,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,   39,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,   76,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  107,  114,
      279,  279,  279,  279,  279,  132,  134,  136,  137,  279,
      279,  279,  149,  279,  161,  279,  279,  279,  279,  279,

      279,  181,  279,  279,  279,  279,  279,  198,  199,  200,
      279,  279,  279,  279,  279,  279,  279,  279,  218,  219,
      279,  221,  279,  237,  241,  279,  279,  279,  249,  255,
      279,  279,  279,  279,  279,  279,  279,  265,  279,  279,
      269,  279,  279,  279,  279,   58,  279,  279,  279,  279,
      279,  279,  279,   68,  279,  279,  279,   77,   79,  279,
      279,  279,  279,   90,  279,  279,  279,  279,  279,  279,
      121,  279,  279,  279,  279,  279,  279,  279,  141,  279,
      279,  279,  279,  279,  279,  176,  279,  279,  183,  279,
      279,  279,  279,  279,  202,  279,  279,  279,  279,  279,

      215,  216,  279,  279,  279,  243,  279,  279,  257,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,   61,  279,  279,  279,   65,  279,  279,  279,
       83,   84,  279,  279,  279,  279,  279,  279,  279,   98,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      162,  279,  279,  279,  279,  279,  191,  279,  279,  279,
      279,  279,  279,  279,  208,  279,  279,  279,  242,  279,
      279,  279,  261,  279,  264,  279,  279,  279,   37,  279,
      279,  279,  279,  279,  279,  279,   64,   70,  279,  279,
      279,  279,  279,  279,  279,   96,   97,  101,  279,  279,

      279,  279,  135,  279,  279,  279,  157,  279,  279,  279,
      177,  180,  279,  279,  279,  279,  203,  279,  204,  279,
      220,  279,  245,  279,  258,  279,  279,  279,  279,  279,
      279,   57,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  170,  279,  279,  279,  279,  201,  279,  279,  279,
      223,  279,  263,  262,  279,  268,  279,  279,  279,  279,
      279,   63,   72,  279,   88,   89,  279,  279,   95,  279,
      279,  279,  279,  138,  279,  279,  279,  279,  279,  279,
      197,  279,  279,  214,  256,  279,  279,  279,  279,  279,

      279,  279,  279,   92,  124,  279,  279,  279,  279,  279,
      167,  279,  194,  279,  279,  279,  279,   42,   56,  279,
       60,  279,   74,   91,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  266,   59,  279,  279,  279,  279,  279,
      279,  279,  195,  279,  205,  279,  129,  130,  131,  140,
      279,  279,  279,   62,  279,  279,  279,  146,  172,  206,
        0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    1,    6,    7,    1,
        1,    8,    9,    1,   10,   11,   12,   13,   14,   15,
       16,   17,   17,   17,   17,   17,   17,   18,   19,   20,
       21,   22,    1,    1,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   41,   42,   43,   44,   45,   46,   46,   46,
        1,    1,    1,    1,   47,    1,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   46,   57,   58,   59,   60,
       61,   62,   63,   64,   65,   66,   67,   68,   69,   70,
       71,   72,    1,   73,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[74] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    2,    2,    2,    2,    2,    1,    1,    1,
        1,    1,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    1
    } ;

static const flex_int16_t yy_base[1463] =
    {   0,
        0,    0, 1591, 1592, 1592, 1592, 1569, 1592, 1583, 1592,
     1567,   65,   66,   64,   76,   78, 1569, 1592,   62, 1565,
       77,   51,   62,   70,   55,   69,   87,  103,   88,  111,
        0, 1525,  104,  120,  127,   46,  122, 1517,  121,  180,
      176,  101, 1522,  137, 1530, 1508, 1592, 1592, 1592, 1592,
     1592, 1592, 1592, 1569,  189, 1592, 1592, 1592,  196,  239,
      205, 1592, 1592, 1592, 1592, 1592, 1592,    0,   47, 1518,
     1530, 1524, 1520, 1513, 1524, 1517, 1524, 1509,   24, 1509,
      129,  142,   97, 1521, 1504, 1519,  209, 1499, 1513, 1500,
     1505,  191,  214, 1514,  168, 1510, 1496, 1509,  219, 1509,

      224, 1496, 1495, 1491, 1494, 1512,  168, 1487, 1503, 1499,
       92, 1487, 1506,    0, 1481, 1485, 1474,  157,  197,  211,
     1513,  227,  224, 1483, 1491, 1500, 1481, 1470, 1474, 1485,
     1485, 1471, 1470, 1462,    0,  238,  203, 1476, 1483, 1470,
      246,  131, 1471, 1492, 1479,   55,  239, 1466, 1469, 1463,
      253, 1459,  238, 1458,  250,    0,    0, 1486, 1460,  193,
      239,  262, 1471,  264, 1456, 1461, 1458, 1451, 1463, 1449,
     1443, 1592, 1592,  321,  326,  335,  308,  341, 1447, 1449,
     1444, 1446, 1451, 1458, 1453,  291, 1444, 1443, 1444, 1435,
     1444, 1449, 1440, 1437,    0, 1438,  307, 1437, 1428,  301,

     1443, 1427, 1439,  266, 1429,  239, 1437, 1424, 1416, 1431,
        0, 1437,  299, 1428, 1427, 1430, 1429, 1432, 1443, 1442,
     1420, 1407, 1419, 1422,  156, 1412, 1414,  281,    0, 1407,
     1405, 1411,  310, 1417, 1427, 1405, 1414,    0, 1414, 1433,
     1435,  343, 1406, 1402, 1407, 1406, 1396, 1395, 1428, 1402,
     1387, 1400, 1397, 1398,  320, 1383,  350, 1396, 1400, 1382,
     1380, 1380,    0, 1382, 1387,    0, 1374,    0, 1388, 1404,
     1389, 1379, 1384,  321, 1379, 1369, 1373, 1378, 1371, 1382,
     1369, 1377, 1376,  314, 1370, 1364, 1357, 1359, 1355, 1369,
     1372, 1359, 1366,    0, 1359,  357, 1360, 1353, 1345, 1358,

     1361, 1350, 1358, 1353, 1352, 1341, 1344,  369, 1352, 1345,
     1353, 1375, 1346, 1334, 1333, 1348, 1330, 1348, 1328, 1346,
     1333, 1340, 1328, 1328, 1337, 1328, 1320, 1326, 1331, 1332,
      355,  413,  418,  428,  433,  438, 1317, 1324,    0, 1315,
     1320, 1314, 1318, 1316, 1320, 1327,    0, 1359, 1317, 1316,
     1319, 1313, 1317, 1317,    0, 1307, 1299,    0, 1313, 1311,
     1315, 1304, 1296, 1324, 1295, 1299, 1293, 1300, 1294,    0,
     1303, 1316,    0, 1286, 1299, 1298, 1289, 1288, 1287, 1280,
     1279, 1296, 1295,    0,    0, 1280, 1310, 1279, 1286, 1274,
     1281, 1270,    0, 1268,    0, 1283, 1306, 1280,    0, 1279,

     1266,    0, 1263, 1281, 1267, 1266, 1264, 1257, 1257, 1274,
     1294, 1279,    0,    0, 1261, 1252, 1277, 1252, 1250, 1250,
     1247, 1254, 1249,    0, 1282, 1296, 1246, 1243,  336, 1245,
        0, 1249, 1240,  360, 1245,  347, 1241, 1236, 1252, 1235,
     1239, 1237, 1235, 1239, 1242, 1237, 1226, 1227, 1224,  348,
        0, 1230, 1240, 1223, 1226, 1235, 1225, 1227, 1218, 1217,
     1214, 1228, 1227, 1225, 1221, 1227, 1226, 1206, 1224, 1205,
     1222, 1209, 1216,    0,    0, 1215, 1200, 1201,  336, 1204,
        0,    0,  356, 1207, 1210, 1197, 1208, 1192, 1198, 1207,
     1208, 1203, 1219,    0,    0, 1219, 1229, 1194, 1209, 1178,

     1183, 1189, 1181, 1192, 1177, 1185, 1178, 1187, 1181, 1183,
     1186,    0, 1179,    0, 1178,    0, 1183, 1176,    0,  443,
      448,    0, 1166, 1197, 1179, 1185, 1178, 1163, 1167, 1166,
        0, 1165,    0, 1160,    0, 1175, 1166, 1173, 1162, 1155,
     1166, 1167, 1164, 1159, 1166, 1161, 1151, 1169, 1150, 1142,
     1152, 1145, 1154, 1145,    0, 1153, 1151, 1150, 1149, 1148,
     1140, 1139,  356, 1144, 1132,    0,    0, 1144, 1129, 1142,
        0, 1122, 1125, 1132,    0, 1133,  431, 1122, 1119, 1122,
     1126, 1120, 1125, 1112, 1126, 1119,    0, 1141, 1113,    0,
     1112, 1121, 1110, 1126, 1109,    0, 1124, 1146, 1122, 1113,

        0, 1098, 1096, 1108, 1109, 1103, 1097, 1101, 1110,    0,
     1111,    0, 1107, 1092, 1106, 1106,    0, 1095,    0, 1113,
     1100, 1088, 1095, 1101, 1089, 1083, 1095, 1098, 1096, 1092,
     1083, 1077, 1089,    0,    0, 1106, 1091, 1088, 1067, 1077,
     1071, 1070, 1079, 1078, 1103,    0, 1075, 1077, 1076,    0,
     1061, 1060, 1064, 1062, 1063, 1062, 1069,  409, 1071, 1065,
     1052, 1067, 1050, 1054, 1062, 1047, 1071, 1059,    0,    0,
     1075,  415, 1053, 1056, 1051, 1081,    0, 1053, 1044,    0,
        0,    0, 1049,    0, 1036, 1049,    0, 1044,    0,    0,
        0, 1084, 1046,    0, 1037, 1036, 1031, 1036, 1056,   21,

      101,    0,  148,  168,  238,  261,  326,  334,  340,  346,
      350,  441,  352,  372,  449,  375,    0,    0,  388,  420,
      423,  420,    0,    0,  421,    0,  426,  424,    0,  433,
      421,  463,  464,  432,    0,  439,  442,  436,  426,  443,
      448,  443,  461,  447,    0,    0,  448,  451,  441,  453,
      456,  445,  434,  470,    0,  454,  437,    0,  446,  470,
      460,  490,  448,    0,  459,  468,    0,  455,    0,  462,
      469,  486,  467,  466,  488,  458,  473,  466,    0,  475,
        0,  480,  469,  465,  490,  484,  468,  479,    0,    0,
      472,  485,    0,    0,  485,    0,  483,    0,  489,    0,

      488,  495,  487,    0,  504,    0,  495,  484,  498,  482,
      485,  491,  503,  502,  516,  508,  497,    0,  492,  511,
        0,  506,    0,  509,  497,  497,    0,    0,  539,  512,
      497,  529,  518,    0,  521,  503,  523,  526,  517,  532,
        0,  532,  536,  529,  534,  526,  562,  525,  530,  525,
      527,  546,  554,    0,    0,  531,  541,  548,  551,    0,
      535,  535,  542,  571,  568,  563,  540,  555,  556,  549,
      558,  561,  550,  542,  580,  565,  550,  565,  559,  567,
      555,  564,  570,  570,  563,  573,  559,  561,  570,  579,
      563,  567,  582,  575,  579,  612,    0,  588,  577,  580,

      571,  588,  589,  578,  577,  609,  580,  592,  586,  601,
      598,  595,  592,  592,  590,    0,  605,    0,  600,  591,
      610,  598,    0,  590,  610,  611,  600,  607,  600,  608,
      601,  609,  606,  605,  621,  629,  610,    0,  638,  622,
      623,  618,  624,  617,  622,  631,  626,  663,    0,  627,
      654,  626,  650,    0,  640,  639,  636,    0,  629,  635,
      636,  636,  643,  644,    0,  641,  643,  639,  638,  643,
        0,  655,    0,  647,  642,  653,    0,  673,  674,  687,
      642,  663,  651,  662,    0,  650,  666,    0,  696,  654,
        0,    0,  693,    0,  670,    0,    0,  692,  660,  697,

      676,  663,    0,  662,  669,  674,    0,    0,  679,  681,
      672,  668,  683,  684,  685,  673,  704,  705,  706,  690,
      677,  692,  681,  692,  683,  682,  695,  691,    0,  699,
      682,  697,  704,  719,    0,  698,  699,  702,  703,  704,
      700,  714,  707,  705,  713,  741,  711,  716,  721,    0,
      733,  716,  706,  720,  726,  711,  711,  728,  723,  719,
      722,  734,  727,  717,    0,  714,  734,  735,  728,  730,
      729,  727,  734,  728,  745,  739,  744,  749,    0,    0,
      733,  731,  760,  761,  772,    0,  762,    0,  760,  739,
      741,  765,    0,  752,  778,  750,  755,  748,  747,  758,

      759,    0,  766,  753,  767,  783,  768,  786,    0,    0,
      767,  771,  772,  773,  761,  793,  777,  758,    0,    0,
      774,    0,  803,    0,    0,  764,  781,  786,    0,    0,
      786,  785,  776,  774,  788,  774,  806,    0,  781,  784,
        0,  779,  784,  795,  789,    0,  796,  796,  799,  800,
      787,  793,  785,    0,  791,  792,  794,    0,    0,  794,
      795,  809,  804,  811,  812,  799,  814,  807,  817,  819,
        0,  818,  824,  825,  826,  808,  827,  828,    0,  846,
      820,  819,  828,  815,  821,    0,  823,  823,    0,  833,
      842,  835,  824,  837,    0,  825,  826,  827,  838,  846,

        0,    0,  834,  840,  845,    0,  839,  832,    0,  840,
      830,  860,  851,  852,  845,  855,  852,  842,  845,  850,
      860,  854,    0,  850,  859,  856,    0,  852,  852,  866,
        0,    0,  854,  860,  872,  887,  876,  861,  873,    0,
      876,  891,  886,  887,  888,  869,  876,  886,  899,  885,
        0,  874,  884,  881,  887,  882,    0,  891,  875,  897,
      881,  892,  893,  894,    0,  879,  891,  894,    0,  901,
      888,  890,    0,  892,    0,  892,  893,  898,    0,  904,
      909,  902,  899,  912,  900,  905,    0,    0,  911,  920,
      905,  916,  905,  924,  913,    0,    0,    0,  926,  948,

      949,  950,    0,  911,  921,  944,    0,  915,  923,  959,
        0,    0,  920,  941,  928,  932,    0,  961,    0,  937,
        0,  938,    0,  939,    0,  936,  938,  928,  926,  935,
      938,    0,  947,  940,  949,  942,  953,  954,  934,  935,
      946,  949,  944,  945,  972,  973,  974,  963,  964,  970,
      962,    0,  958,  954,  969,  957,    0,  965,  963,  961,
        0,  961,    0,    0,  979,    0,  968,  979,  970,  965,
      982,    0,    0,  981,    0,    0,  970,  983,    0,  981,
      996,  997,  998,    0, 1004, 1000,  994,  976,  979,  981,
        0,  994,  996,    0,    0,  988,  984,  998, 1001,  987,

      987,  989,  984,    0,    0, 1025, 1026, 1027, 1011, 1035,
        0, 1001,    0,  996, 1004, 1012,  999,    0,    0, 1014,
        0, 1011,    0,    0, 1031, 1032, 1033, 1012, 1042, 1022,
     1009, 1023, 1011,    0,    0, 1016, 1042, 1043, 1044, 1029,
     1055, 1035,    0, 1024,    0, 1025,    0,    0,    0,    0,
     1051, 1023, 1022,    0, 1062, 1019, 1026,    0,    0,    0,
     1592, 1090
    } ;

static const flex_int16_t yy_def[1463] =
    {   0,
     1461,    1, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1461, 1461, 1461, 1461, 1461, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1461,
     1461, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,

     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
     1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462, 1462,
        0, 1461
    } ;

static const flex_int16_t yy_nxt[1666] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   16,   16,   16,   16,   17,   18,   19,
       20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   45,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   46,   50,   54,   52,   55,   55,   55,   55,
       55,   63,   64,   56,  834,   51,   53,   57,   59,  190,
       60,   60,   60,   60,   60,  191,   58,   66,   67,   69,

       70,   71,   78,   72,   61,  130,   92,  179,   73,  131,
       93,  180,   74,   79,   75,   76,   77,   82,   94,   80,
      296,   83,   81,  297,   84,   85,   95,   86,   96,   61,
       87,   88,   97,   89,  100,   98,   90,  106,   99,  109,
       91,  126,  101,  110,  102,  103,  113,  104,  111,  246,
      247,  117,  198,  105,  107,  118,  199,  121,  112,  119,
      164,  108,  165,  114,  120,  166,  835,  122,  140,  132,
      115,  123,  141,  133,  127,  124,  134,  135,  128,  136,
      125,  142,  137,  388,  168,  138,  389,  143,  169,  193,
      156,  157,  170,  129,  144,  194,  291,  292,  195,  196,

      836,   55,   55,   55,   55,   55,  158,  197,  175,  175,
      175,  175,  175,  177,  177,  174,  253,  178,  178,  178,
      178,  178,  176,  159,  254,  223,  837,  160,  241,  145,
      161,  146,  224,  242,  147,  148,  162,  149,  150,  163,
      174,  151,  152,  215,  216,  153,  154,  176,  217,   59,
      155,   60,   60,   60,   60,   60,  255,  314,  279,  203,
      280,  256,  315,  204,  257,   61,  205,  206,  207,  208,
      209,  218,  219,  210,  228,  232,  260,  220,  221,  258,
      229,  233,  264,  234,  230,  277,  298,  368,  265,  307,
       61,  261,  262,  235,  316,  284,  263,  838,  285,  299,

      369,  308,  317,  286,  278,  287,  288,  303,  310,  311,
      304,  289,  318,  290,  322,  344,  305,  365,  839,  323,
      178,  178,  178,  178,  178,  319,  366,  320,  324,  332,
      332,  345,  346,  333,  333,  333,  333,  333,  175,  175,
      175,  175,  175,  335,  335,  392,  393,  336,  336,  336,
      336,  336,  334,  178,  178,  178,  178,  178,  356,  360,
      423,  397,  375,  426,  361,  357,  376,  398,  441,  406,
      407,  424,  442,  840,  452,  599,  600,  334,  408,  453,
      454,  465,  604,  409,  466,  841,  410,  607,  608,  622,
      427,  467,  468,  483,  469,  649,  484,  470,  471,  842,

      605,  650,  485,  652,  513,  843,  486,  514,  487,  488,
      653,  623,  515,  622,  654,  844,  516,  847,  517,  518,
      721,  722,  519,  848,  489,  333,  333,  333,  333,  333,
      333,  333,  333,  333,  333,  490,  520,  520,  852,  853,
      521,  521,  521,  521,  521,  336,  336,  336,  336,  336,
      336,  336,  336,  336,  336,  521,  521,  521,  521,  521,
      521,  521,  521,  521,  521,  732,  802,  815,  733,  845,
      803,  854,  816,  849,  855,  858,  859,  860,  856,  861,
      862,  863,  846,  857,  850,  864,  866,  867,  868,  851,
      869,  870,  871,  865,  872,  873,  874,  875,  876,  877,

      878,  879,  880,  881,  882,  883,  884,  885,  886,  887,
      888,  889,  890,  892,  893,  894,  895,  896,  897,  898,
      900,  901,  902,  903,  904,  905,  906,  907,  908,  891,
      909,  910,  911,  912,  913,  914,  915,  916,  917,  918,
      919,  899,  920,  898,  921,  922,  923,  924,  925,  926,
      927,  928,  929,  930,  931,  934,  935,  936,  937,  938,
      939,  940,  941,  942,  943,  948,  944,  949,  950,  945,
      951,  932,  952,  953,  954,  955,  933,  956,  931,  946,
      957,  947,  958,  959,  960,  961,  962,  963,  965,  964,
      966,  967,  968,  969,  970,  971,  972,  973,  974,  975,

      976,  977,  978,  979,  980,  981,  982,  983,  984,  985,
      986,  987,  988,  989,  990,  991,  992,  993,  994,  995,
      996,  997,  998,  999, 1000, 1001, 1002, 1003, 1004, 1005,
     1006, 1007, 1008, 1009, 1010, 1012, 1013, 1014, 1015, 1016,
     1017, 1018, 1019, 1020, 1021, 1022, 1023, 1011, 1024, 1025,
     1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1010,
     1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044,
     1045, 1011, 1046, 1047, 1048, 1049, 1050, 1051, 1052, 1054,
     1055, 1057, 1058, 1056, 1053, 1059, 1060, 1061, 1062, 1063,
     1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071, 1072, 1073,

     1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081, 1082, 1083,
     1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091, 1092, 1093,
     1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101, 1102, 1103,
     1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113,
     1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 1122, 1123,
     1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133,
     1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143,
     1144, 1146, 1147, 1148, 1145, 1149, 1150, 1151, 1152, 1153,
     1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163,
     1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173,

     1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183,
     1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191, 1192, 1193,
     1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201, 1202, 1203,
     1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213,
     1214, 1215, 1192, 1216, 1217, 1218, 1219, 1220, 1221, 1222,
     1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232,
     1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242,
     1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252,
     1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261, 1262,
     1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270, 1271, 1272,

     1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281, 1258,
     1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291,
     1292, 1293, 1294, 1295, 1296, 1274, 1297, 1298, 1299, 1300,
     1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310,
     1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320,
     1321, 1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330,
     1331, 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340,
     1341, 1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350,
     1351, 1352, 1353, 1354, 1355, 1356, 1357, 1358, 1360, 1361,
     1362, 1363, 1364, 1365, 1366, 1367, 1359, 1368, 1369, 1370,

     1371, 1372, 1373, 1374, 1375, 1376, 1377, 1378, 1355, 1379,
     1380, 1381, 1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389,
     1390, 1391, 1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399,
     1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409,
     1410, 1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419,
     1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429,
     1430, 1431, 1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439,
     1440, 1441, 1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449,
     1450, 1451, 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459,
     1460,   68,  833,  832,  831,  830,  829,  828,  827,  826,

      825,  824,  823,  822,  821,  820,  819,  818,  817,  814,
      813,  812,  811,  810,  809,  808,  807,  806,  805,  804,
      801,  800,  799,  798,  797,  796,  795,  794,  793,  792,
      791,  790,  789,  788,  787,  786,  785,  784,  783,  782,
      781,  780,  779,  778,  777,  776,  775,  774,  773,  772,
      771,  770,  769,  768,  767,  766,  765,  764,  763,  762,
      761,  760,  759,  758,  757,  756,  755,  754,  753,  752,
      751,  750,  749,  748,  747,  746,  745,  744,  743,  742,
      741,  740,  739,  738,  737,  736,  735,  734,  731,  730,
      729,  728,  727,  726,  725,  724,  723,  720,  719,  718,

      717,  716,  715,  714,  713,  712,  711,  710,  709,  708,
      707,  706,  705,  704,  703,  702,  701,  700,  699,  698,
      697,  696,  695,  694,  693,  692,  691,  690,  689,  688,
      687,  686,  685,  684,  683,  682,  681,  680,  679,  678,
      677,  676,  675,  674,  673,  672,  671,  670,  669,  668,
      667,  666,  665,  664,  663,  662,  661,  660,  659,  658,
      657,  656,  655,  651,  648,  647,  646,  645,  644,  643,
      642,  641,  640,  639,  638,  637,  636,  635,  634,  633,
      632,  631,  630,  629,  628,  627,  626,  625,  624,  621,
      620,  619,  618,  617,  616,  615,  614,  613,  612,  611,

      610,  609,  606,  603,  602,  601,  598,  597,  596,  595,
      594,  593,  592,  591,  590,  589,  588,  587,  586,  585,
      584,  583,  582,  581,  580,  579,  578,  577,  576,  575,
      574,  573,  572,  571,  570,  569,  568,  567,  566,  565,
      564,  563,  562,  561,  560,  559,  558,  557,  556,  555,
      554,  553,  552,  551,  550,  549,  548,  547,  546,  545,
      544,  543,  542,  541,  540,  539,  538,  537,  536,  535,
      534,  533,  532,  531,  530,  529,  528,  527,  526,  525,
      524,  523,  522,  512,  511,  510,  509,  508,  507,  506,
      505,  504,  503,  502,  501,  500,  499,  498,  497,  496,

      495,  494,  493,  492,  491,  482,  481,  480,  479,  478,
      477,  476,  475,  474,  473,  472,  464,  463,  462,  461,
      460,  459,  458,  457,  456,  455,  451,  450,  449,  448,
      447,  446,  445,  444,  443,  440,  439,  438,  437,  436,
      435,  434,  433,  432,  431,  430,  429,  428,  425,  422,
      421,  420,  419,  418,  417,  416,  415,  414,  413,  412,
      411,  405,  404,  403,  402,  401,  400,  399,  396,  395,
      394,  391,  390,  387,  386,  385,  384,  383,  382,  381,
      380,  379,  378,  377,  374,  373,  372,  371,  370,  367,
      364,  363,  362,  359,  358,  355,  354,  353,  352,  351,

      350,  349,  348,  347,  343,  342,  341,  340,  339,  338,
      337,  331,  330,  329,  328,  327,  326,  325,  321,  313,
      312,  309,  306,  302,  301,  300,  295,  294,  293,  283,
      282,  281,  276,  275,  274,  273,  272,  271,  270,  269,
      268,  267,  266,  259,  252,  251,  250,  249,  248,  245,
      244,  243,  240,  239,  238,  237,  236,  231,  227,  226,
      225,  222,  214,  213,  212,  211,  202,  201,  200,  192,
      189,  188,  187,  186,  185,  184,  183,  182,  181,  173,
      172,  171,  167,  139,  116,   65,   62,   49,   48,   47,
     1461,    3, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,

     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461
    } ;

static const flex_int16_t yy_chk[1666] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   12,   14,   13,   14,   14,   14,   14,
       14,   19,   19,   15,  700,   12,   13,   15,   16,   79,
       16,   16,   16,   16,   16,   79,   15,   21,   21,   22,

       22,   22,   23,   22,   16,   36,   25,   69,   22,   36,
       25,   69,   22,   23,   22,   22,   22,   24,   25,   23,
      146,   24,   23,  146,   24,   24,   26,   24,   26,   16,
       24,   24,   26,   24,   27,   26,   24,   28,   26,   29,
       24,   35,   27,   29,   27,   27,   30,   27,   29,  111,
      111,   33,   83,   27,   28,   33,   83,   34,   29,   33,
       42,   28,   42,   30,   33,   42,  701,   34,   39,   37,
       30,   34,   39,   37,   35,   34,   37,   37,   35,   37,
       34,   39,   37,  225,   44,   37,  225,   39,   44,   81,
       41,   41,   44,   35,   40,   81,  142,  142,   81,   82,

      703,   55,   55,   55,   55,   55,   41,   82,   59,   59,
       59,   59,   59,   61,   61,   55,  118,   61,   61,   61,
       61,   61,   59,   41,  118,   95,  704,   41,  107,   40,
       41,   40,   95,  107,   40,   40,   41,   40,   40,   41,
       55,   40,   40,   92,   92,   40,   40,   59,   92,   60,
       40,   60,   60,   60,   60,   60,  119,  160,  137,   87,
      137,  119,  160,   87,  120,   60,   87,   87,   87,   87,
       87,   93,   93,   87,   99,  101,  122,   93,   93,  120,
       99,  101,  123,  101,   99,  136,  147,  206,  123,  153,
       60,  122,  122,  101,  161,  141,  122,  705,  141,  147,

      206,  153,  161,  141,  136,  141,  141,  151,  155,  155,
      151,  141,  162,  141,  164,  186,  151,  204,  706,  164,
      177,  177,  177,  177,  177,  162,  204,  162,  164,  174,
      174,  186,  186,  174,  174,  174,  174,  174,  175,  175,
      175,  175,  175,  176,  176,  228,  228,  176,  176,  176,
      176,  176,  175,  178,  178,  178,  178,  178,  197,  200,
      255,  233,  213,  257,  200,  197,  213,  233,  274,  242,
      242,  255,  274,  707,  284,  429,  429,  175,  242,  284,
      284,  296,  434,  242,  296,  708,  242,  436,  436,  450,
      257,  296,  296,  308,  296,  479,  308,  296,  296,  709,

      434,  479,  308,  483,  331,  710,  308,  331,  308,  308,
      483,  450,  331,  450,  483,  711,  331,  713,  331,  331,
      563,  563,  331,  714,  308,  332,  332,  332,  332,  332,
      333,  333,  333,  333,  333,  308,  334,  334,  716,  719,
      334,  334,  334,  334,  334,  335,  335,  335,  335,  335,
      336,  336,  336,  336,  336,  520,  520,  520,  520,  520,
      521,  521,  521,  521,  521,  577,  658,  672,  577,  712,
      658,  720,  672,  715,  721,  722,  725,  727,  721,  728,
      730,  731,  712,  721,  715,  732,  733,  734,  736,  715,
      737,  738,  739,  732,  740,  741,  742,  743,  744,  747,

      748,  749,  750,  751,  752,  753,  754,  756,  757,  759,
      760,  761,  762,  763,  765,  766,  768,  770,  771,  772,
      773,  774,  775,  776,  777,  778,  780,  782,  783,  762,
      784,  785,  786,  787,  788,  791,  792,  795,  797,  799,
      801,  772,  802,  772,  803,  805,  807,  808,  809,  810,
      811,  812,  813,  814,  815,  816,  817,  819,  820,  822,
      824,  825,  826,  829,  829,  830,  829,  831,  832,  829,
      833,  815,  835,  836,  837,  838,  815,  839,  815,  829,
      840,  829,  842,  843,  844,  845,  846,  847,  848,  847,
      849,  850,  851,  852,  853,  856,  857,  858,  859,  861,

      862,  863,  864,  865,  866,  867,  868,  869,  870,  871,
      872,  873,  874,  875,  876,  877,  878,  879,  880,  881,
      882,  883,  884,  885,  886,  887,  888,  889,  890,  891,
      892,  893,  894,  895,  896,  898,  899,  900,  901,  902,
      903,  904,  905,  906,  907,  908,  909,  896,  910,  911,
      912,  913,  914,  915,  917,  919,  920,  921,  922,  896,
      924,  925,  926,  927,  928,  929,  930,  931,  932,  933,
      934,  896,  935,  936,  937,  939,  940,  941,  942,  943,
      944,  945,  946,  944,  942,  947,  948,  950,  951,  952,
      953,  955,  956,  957,  959,  960,  961,  962,  963,  964,

      966,  967,  968,  969,  970,  972,  974,  975,  976,  978,
      979,  980,  981,  982,  983,  984,  986,  987,  989,  990,
      993,  995,  998,  999, 1000, 1001, 1002, 1004, 1005, 1006,
     1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018,
     1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028,
     1030, 1031, 1032, 1033, 1034, 1036, 1037, 1038, 1039, 1040,
     1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1051,
     1052, 1053, 1054, 1055, 1052, 1056, 1057, 1058, 1059, 1060,
     1061, 1062, 1063, 1064, 1066, 1067, 1068, 1069, 1070, 1071,
     1072, 1073, 1074, 1075, 1076, 1077, 1078, 1081, 1082, 1083,

     1084, 1085, 1087, 1089, 1090, 1091, 1092, 1094, 1095, 1096,
     1097, 1098, 1099, 1100, 1101, 1103, 1104, 1105, 1106, 1107,
     1108, 1111, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1121,
     1123, 1126, 1127, 1128, 1131, 1132, 1133, 1134, 1135, 1136,
     1137, 1139, 1106, 1140, 1142, 1143, 1144, 1145, 1147, 1148,
     1149, 1150, 1151, 1152, 1153, 1155, 1156, 1157, 1160, 1161,
     1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170, 1172,
     1173, 1174, 1175, 1176, 1177, 1178, 1180, 1181, 1182, 1183,
     1184, 1185, 1187, 1188, 1190, 1191, 1192, 1193, 1194, 1196,
     1197, 1198, 1199, 1200, 1203, 1204, 1205, 1207, 1208, 1210,

     1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1191,
     1220, 1221, 1222, 1224, 1225, 1226, 1228, 1229, 1230, 1233,
     1234, 1235, 1236, 1237, 1238, 1212, 1239, 1241, 1242, 1243,
     1244, 1245, 1246, 1247, 1248, 1249, 1250, 1252, 1253, 1254,
     1255, 1256, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 1266,
     1267, 1268, 1270, 1271, 1272, 1274, 1276, 1277, 1278, 1280,
     1281, 1282, 1283, 1284, 1285, 1286, 1289, 1290, 1291, 1292,
     1293, 1294, 1295, 1299, 1300, 1301, 1302, 1304, 1305, 1306,
     1308, 1309, 1310, 1313, 1314, 1315, 1316, 1318, 1320, 1322,
     1324, 1326, 1327, 1328, 1329, 1330, 1318, 1331, 1333, 1334,

     1335, 1336, 1337, 1338, 1339, 1340, 1341, 1342, 1314, 1343,
     1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1353, 1354,
     1355, 1356, 1358, 1359, 1360, 1362, 1365, 1367, 1368, 1369,
     1370, 1371, 1374, 1377, 1378, 1380, 1381, 1382, 1383, 1385,
     1386, 1387, 1388, 1389, 1390, 1392, 1393, 1396, 1397, 1398,
     1399, 1400, 1401, 1402, 1403, 1406, 1407, 1408, 1409, 1410,
     1412, 1414, 1415, 1416, 1417, 1420, 1422, 1425, 1426, 1427,
     1428, 1429, 1430, 1431, 1432, 1433, 1436, 1437, 1438, 1439,
     1440, 1441, 1442, 1444, 1446, 1451, 1452, 1453, 1455, 1456,
     1457, 1462,  699,  698,  697,  696,  695,  693,  692,  688,

      686,  685,  683,  679,  678,  676,  675,  674,  673,  671,
      668,  667,  666,  665,  664,  663,  662,  661,  660,  659,
      657,  656,  655,  654,  653,  652,  651,  649,  648,  647,
      645,  644,  643,  642,  641,  640,  639,  638,  637,  636,
      633,  632,  631,  630,  629,  628,  627,  626,  625,  624,
      623,  622,  621,  620,  618,  616,  615,  614,  613,  611,
      609,  608,  607,  606,  605,  604,  603,  602,  600,  599,
      598,  597,  595,  594,  593,  592,  591,  589,  588,  586,
      585,  584,  583,  582,  581,  580,  579,  578,  576,  574,
      573,  572,  570,  569,  568,  565,  564,  562,  561,  560,

      559,  558,  557,  556,  554,  553,  552,  551,  550,  549,
      548,  547,  546,  545,  544,  543,  542,  541,  540,  539,
      538,  537,  536,  534,  532,  530,  529,  528,  527,  526,
      525,  524,  523,  518,  517,  515,  513,  511,  510,  509,
      508,  507,  506,  505,  504,  503,  502,  501,  500,  499,
      498,  497,  496,  493,  492,  491,  490,  489,  488,  487,
      486,  485,  484,  480,  478,  477,  476,  473,  472,  471,
      470,  469,  468,  467,  466,  465,  464,  463,  462,  461,
      460,  459,  458,  457,  456,  455,  454,  453,  452,  449,
      448,  447,  446,  445,  444,  443,  442,  441,  440,  439,

      438,  437,  435,  433,  432,  430,  428,  427,  426,  425,
      423,  422,  421,  420,  419,  418,  417,  416,  415,  412,
      411,  410,  409,  408,  407,  406,  405,  404,  403,  401,
      400,  398,  397,  396,  394,  392,  391,  390,  389,  388,
      387,  386,  383,  382,  381,  380,  379,  378,  377,  376,
      375,  374,  372,  371,  369,  368,  367,  366,  365,  364,
      363,  362,  361,  360,  359,  357,  356,  354,  353,  352,
      351,  350,  349,  348,  346,  345,  344,  343,  342,  341,
      340,  338,  337,  330,  329,  328,  327,  326,  325,  324,
      323,  322,  321,  320,  319,  318,  317,  316,  315,  314,

      313,  312,  311,  310,  309,  307,  306,  305,  304,  303,
      302,  301,  300,  299,  298,  297,  295,  293,  292,  291,
      290,  289,  288,  287,  286,  285,  283,  282,  281,  280,
      279,  278,  277,  276,  275,  273,  272,  271,  270,  269,
      267,  265,  264,  262,  261,  260,  259,  258,  256,  254,
      253,  252,  251,  250,  249,  248,  247,  246,  245,  244,
      243,  241,  240,  239,  237,  236,  235,  234,  232,  231,
      230,  227,  226,  224,  223,  222,  221,  220,  219,  218,
      217,  216,  215,  214,  212,  210,  209,  208,  207,  205,
      203,  202,  201,  199,  198,  196,  194,  193,  192,  191,

      190,  189,  188,  187,  185,  184,  183,  182,  181,  180,
      179,  171,  170,  169,  168,  167,  166,  165,  163,  159,
      158,  154,  152,  150,  149,  148,  145,  144,  143,  140,
      139,  138,  134,  133,  132,  131,  130,  129,  128,  127,
      126,  125,  124,  121,  117,  116,  115,  113,  112,  110,
      109,  108,  106,  105,  104,  103,  102,  100,   98,   97,
       96,   94,   91,   90,   89,   88,   86,   85,   84,   80,
       78,   77,   76,   75,   74,   73,   72,   71,   70,   54,
       46,   45,   43,   38,   32,   20,   17,   11,    9,    7,
        3, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,

     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461, 1461,
     1461, 1461, 1461, 1461, 1461
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "Gmsh.l"
#line 2 "Gmsh.l"
// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
//
// See the LICENSE.txt file in the Gmsh root directory for license information.
// Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.

#include <algorithm>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include "GmshConfig.h"
#include "GmshMessage.h"
#include "GModelIO_GEO.h"
#include "Geo.h" // for Shape, NEWPOINT(), etc.
#include "Parser.h"
#include "Gmsh.tab.hpp"

void   parsestring(char endchar);
char  *strsave(char *ptr);
void   skipcomments(void);
void   skipline(void);

#define YY_INPUT(buf,result,max_size)					\
  {									\
    int c = '*', n;							\
    for(n = 0; n < (int) max_size && (c = fgetc(yyin)) != EOF &&        \
           c != '\n' && c != '\r'; ++n)                                 \
      buf[n] = (char) c;                                                \
    if(c == '\n' || c == '\r') {                                        \
      buf[n++] = (char) c;                                              \
      if(c == '\n') yylineno++;                                         \
    }                                                                   \
    if(c == EOF && ferror(yyin))                                        \
      Msg::Error("Input in flex scanner failed");			\
    result = n;                                                         \
  }

#if defined(WIN32)
#define isatty(arg) -1
#define YY_NO_UNISTD_H
#endif

// undefine register for C++11 compatibility of files generated with old
// versions of flex/bison
#define register

#line 1599 "Gmsh.yy.cpp"
#line 1600 "Gmsh.yy.cpp"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			yy_size_t yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 57 "Gmsh.l"


#line 1820 "Gmsh.yy.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1462 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1592 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 59 "Gmsh.l"
/* none */;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 60 "Gmsh.l"
return tEND;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 61 "Gmsh.l"
skipcomments();
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 62 "Gmsh.l"
skipline();
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 63 "Gmsh.l"
{ parsestring('\"'); return tBIGSTR; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 64 "Gmsh.l"
{ parsestring('\''); return tBIGSTR; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 65 "Gmsh.l"
{ gmsh_yylval.d = NEWREG(); return tDOUBLE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 66 "Gmsh.l"
{ gmsh_yylval.d = NEWPOINT(); return tDOUBLE; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 67 "Gmsh.l"
{ gmsh_yylval.d = NEWCURVE(); return tDOUBLE; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 68 "Gmsh.l"
{ gmsh_yylval.d = NEWCURVE(); return tDOUBLE; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 69 "Gmsh.l"
{ gmsh_yylval.d = NEWCURVELOOP(); return tDOUBLE; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 70 "Gmsh.l"
{ gmsh_yylval.d = NEWCURVELOOP(); return tDOUBLE; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 71 "Gmsh.l"
{ gmsh_yylval.d = NEWSURFACE(); return tDOUBLE; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 72 "Gmsh.l"
{ gmsh_yylval.d = NEWSURFACELOOP(); return tDOUBLE; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 73 "Gmsh.l"
{ gmsh_yylval.d = NEWVOLUME(); return tDOUBLE; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 74 "Gmsh.l"
{ gmsh_yylval.d = NEWFIELD(); return tDOUBLE; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 75 "Gmsh.l"
return tAFFECT;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 76 "Gmsh.l"
return tAFFECTPLUS;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 77 "Gmsh.l"
return tAFFECTMINUS;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 78 "Gmsh.l"
return tAFFECTTIMES;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 79 "Gmsh.l"
return tAFFECTDIVIDE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 80 "Gmsh.l"
return tDOTS;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 81 "Gmsh.l"
return tDOTS;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 82 "Gmsh.l"
return tSCOPE;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 83 "Gmsh.l"
return tOR;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 84 "Gmsh.l"
return tAND;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 85 "Gmsh.l"
return tPLUSPLUS;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 86 "Gmsh.l"
return tMINUSMINUS;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 87 "Gmsh.l"
return tEQUAL;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 88 "Gmsh.l"
return tNOTEQUAL;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 89 "Gmsh.l"
return tLESSOREQUAL;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 90 "Gmsh.l"
return tGREATEROREQUAL;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 91 "Gmsh.l"
return tGREATERGREATER;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 92 "Gmsh.l"
return tLESSLESS;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 94 "Gmsh.l"
return tAbort;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 95 "Gmsh.l"
return tAbs;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 96 "Gmsh.l"
return tAbsolutePath;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 97 "Gmsh.l"
return tAcos;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 98 "Gmsh.l"
return tAdaptMesh;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 99 "Gmsh.l"
return tAffine;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 100 "Gmsh.l"
return tAlias;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 101 "Gmsh.l"
return tAliasWithOptions;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 102 "Gmsh.l"
return tAcos;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 103 "Gmsh.l"
return tAppend;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 104 "Gmsh.l"
return tAsin;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 105 "Gmsh.l"
return tAtan;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 106 "Gmsh.l"
return tAtan2;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 107 "Gmsh.l"
return tAsin;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 108 "Gmsh.l"
return tAtan;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 109 "Gmsh.l"
return tAtan2;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 111 "Gmsh.l"
return tBSpline;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 112 "Gmsh.l"
return tBetti;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 113 "Gmsh.l"
return tBezier;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 114 "Gmsh.l"
return tBox;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 115 "Gmsh.l"
return tBox;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 116 "Gmsh.l"
return tBooleanFragments;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 117 "Gmsh.l"
return tBooleanIntersection;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 118 "Gmsh.l"
return tBooleanDifference;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 119 "Gmsh.l"
return tBooleanDifference;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 120 "Gmsh.l"
return tBooleanFragments;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 121 "Gmsh.l"
return tBooleanUnion;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 122 "Gmsh.l"
return tBooleanIntersection;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 123 "Gmsh.l"
return tBooleanSection;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 124 "Gmsh.l"
return tBooleanUnion;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 125 "Gmsh.l"
return tBoundingBox;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 127 "Gmsh.l"
return tCall;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 128 "Gmsh.l"
return tCatenary;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 129 "Gmsh.l"
return tSpline;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 130 "Gmsh.l"
return tCeil;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 131 "Gmsh.l"
return tCenterOfMass;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 132 "Gmsh.l"
return tChamfer;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 133 "Gmsh.l"
return tCharacteristic;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 134 "Gmsh.l"
return tCircle;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 135 "Gmsh.l"
return tClassifySurfaces;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 136 "Gmsh.l"
return tCodeName;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 137 "Gmsh.l"
return tCoherence;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 138 "Gmsh.l"
return tCohomology;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 139 "Gmsh.l"
return tColor;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 140 "Gmsh.l"
return tColorTable;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 141 "Gmsh.l"
return tCombine;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 142 "Gmsh.l"
return tCompound;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 143 "Gmsh.l"
return tCone;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 144 "Gmsh.l"
return tCoordinates;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 145 "Gmsh.l"
return tCopyOptions;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 146 "Gmsh.l"
return tCos;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 147 "Gmsh.l"
return tCosh;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 148 "Gmsh.l"
return tCpu;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 149 "Gmsh.l"
return tCreateGeometry;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 150 "Gmsh.l"
return tCreateTopology;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 151 "Gmsh.l"
return tCurrentDirectory;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 152 "Gmsh.l"
return tCurrentDirectory;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 153 "Gmsh.l"
return tCurrentFileName;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 154 "Gmsh.l"
return tCurve;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 155 "Gmsh.l"
return tCylinder;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 157 "Gmsh.l"
return tDefineConstant;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 158 "Gmsh.l"
return tDefineNumber;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 159 "Gmsh.l"
return tDefineString;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 160 "Gmsh.l"
return tDegenerated;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 161 "Gmsh.l"
return tDelete;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 162 "Gmsh.l"
return tDilate;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 163 "Gmsh.l"
return tDimNameSpace;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 164 "Gmsh.l"
return tDirName;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 165 "Gmsh.l"
return tDisk;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 166 "Gmsh.l"
return tDraw;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 168 "Gmsh.l"
return tEllipse;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 169 "Gmsh.l"
return tEllipse;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 170 "Gmsh.l"
return tEllipsoid;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 171 "Gmsh.l"
return tElliptic;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 172 "Gmsh.l"
return tElse;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 173 "Gmsh.l"
return tElseIf;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 174 "Gmsh.l"
return tEndFor;
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 175 "Gmsh.l"
return tEndIf;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 176 "Gmsh.l"
return tError;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 177 "Gmsh.l"
return tEuclidian;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 178 "Gmsh.l"
return tExists;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 179 "Gmsh.l"
return tExit;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 180 "Gmsh.l"
return tExp;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 181 "Gmsh.l"
return tExtrude;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 183 "Gmsh.l"
return tFabs;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 184 "Gmsh.l"
return tField;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 185 "Gmsh.l"
return tFileExists;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 186 "Gmsh.l"
return tFillet;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 187 "Gmsh.l"
return tFind;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 188 "Gmsh.l"
return tFixRelativePath;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 189 "Gmsh.l"
return tFloor;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 190 "Gmsh.l"
return tFmod;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 191 "Gmsh.l"
return tFor;
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 192 "Gmsh.l"
return tMacro;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 194 "Gmsh.l"
return tGMSH_MAJOR_VERSION;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 195 "Gmsh.l"
return tGMSH_MINOR_VERSION;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 196 "Gmsh.l"
return tGMSH_PATCH_VERSION;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 197 "Gmsh.l"
return tGeoEntity;
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 198 "Gmsh.l"
return tGetEnv;
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 199 "Gmsh.l"
return tGetForced;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 200 "Gmsh.l"
return tGetForcedStr;
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 201 "Gmsh.l"
return tGetNumber;
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 202 "Gmsh.l"
return tGetString;
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 203 "Gmsh.l"
return tGetStringValue;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 204 "Gmsh.l"
return tGetValue;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 205 "Gmsh.l"
return tGmshExecutableName;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 207 "Gmsh.l"
return tHealShapes;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 208 "Gmsh.l"
return tHide;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 209 "Gmsh.l"
return tHole;
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 210 "Gmsh.l"
return tHomology;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 211 "Gmsh.l"
return tHypot;
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 213 "Gmsh.l"
return tInterpolationScheme;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 214 "Gmsh.l"
return tIf;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 215 "Gmsh.l"
return tIn;
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 216 "Gmsh.l"
return tIntersect;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 218 "Gmsh.l"
return tNurbsKnots;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 220 "Gmsh.l"
return tLayers;
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 221 "Gmsh.l"
return tLength;
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 222 "Gmsh.l"
return tLevelset;
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 223 "Gmsh.l"
return tLinSpace;
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 224 "Gmsh.l"
return tCurve;
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 225 "Gmsh.l"
return tList;
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 226 "Gmsh.l"
return tListFromFile;
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 227 "Gmsh.l"
return tLog;
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 228 "Gmsh.l"
return tLog10;
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 229 "Gmsh.l"
return tLogSpace;
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 230 "Gmsh.l"
return tLowerCase;
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 231 "Gmsh.l"
return tLowerCaseIn;
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 233 "Gmsh.l"
return tMPI_Rank;
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 234 "Gmsh.l"
return tMPI_Size;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 235 "Gmsh.l"
return tMacro;
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 236 "Gmsh.l"
return tMass;
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 237 "Gmsh.l"
return tMatrixOfInertia;
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 238 "Gmsh.l"
return tMax;
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 239 "Gmsh.l"
return tMemory;
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 240 "Gmsh.l"
return tMeshAlgorithm;
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 241 "Gmsh.l"
return tMeshSize;
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 242 "Gmsh.l"
return tMeshSizeFromBoundary;
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 243 "Gmsh.l"
return tMin;
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 244 "Gmsh.l"
return tModulo;
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 246 "Gmsh.l"
return tNameToString;
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 247 "Gmsh.l"
return tNameStruct;
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 248 "Gmsh.l"
return tNameToString;
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 249 "Gmsh.l"
return tNewModel;
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 250 "Gmsh.l"
return tNurbs;
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 252 "Gmsh.l"
return tOnelabAction;
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 253 "Gmsh.l"
return tOnelabRun;
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 254 "Gmsh.l"
return tNurbsOrder;
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 256 "Gmsh.l"
return tParametric;
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 257 "Gmsh.l"
return tParent;
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 258 "Gmsh.l"
return tPeriodic;
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 259 "Gmsh.l"
return tPhysical;
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 260 "Gmsh.l"
return tPi;
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 261 "Gmsh.l"
return tPlane;
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 262 "Gmsh.l"
return tPlugin;
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 263 "Gmsh.l"
return tPoint;
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 264 "Gmsh.l"
return tPolarSphere;
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 265 "Gmsh.l"
return tPrintf;
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 267 "Gmsh.l"
return tQuadric;
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 268 "Gmsh.l"
return tQuadTriAddVerts;
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 269 "Gmsh.l"
return tQuadTriNoNewVerts;
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 271 "Gmsh.l"
return tRand;
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 272 "Gmsh.l"
return tRecombLaterals;
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 273 "Gmsh.l"
return tRecombine;
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 274 "Gmsh.l"
return tRectangle;
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 275 "Gmsh.l"
return tRecursive;
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 276 "Gmsh.l"
return tRecombineMesh;
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 277 "Gmsh.l"
return tRefineMesh;
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 278 "Gmsh.l"
return tRelocateMesh;
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 279 "Gmsh.l"
return tReorientMesh;
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 280 "Gmsh.l"
return tRenumberMeshNodes;
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 281 "Gmsh.l"
return tRenumberMeshElements;
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 282 "Gmsh.l"
return tReturn;
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 283 "Gmsh.l"
return tReverseMesh;
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 284 "Gmsh.l"
return tReverseMesh;
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 285 "Gmsh.l"
return tRotate;
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 286 "Gmsh.l"
return tRound;
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 287 "Gmsh.l"
return tRuled;
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 289 "Gmsh.l"
return tStringToName;
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 290 "Gmsh.l"
return tScaleLast;
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 291 "Gmsh.l"
return tSetChanged;
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 292 "Gmsh.l"
return tSetFactory;
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 293 "Gmsh.l"
return tSetTag;
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 294 "Gmsh.l"
return tSetMaxTag;
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 295 "Gmsh.l"
return tSetNumber;
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 296 "Gmsh.l"
return tSetPartition;
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 297 "Gmsh.l"
return tSetString;
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 298 "Gmsh.l"
return tSewing;
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 299 "Gmsh.l"
return tShapeFromFile;
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 300 "Gmsh.l"
return tShow;
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 301 "Gmsh.l"
return tSin;
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 302 "Gmsh.l"
return tSinh;
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 303 "Gmsh.l"
return tSlide;
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 304 "Gmsh.l"
return tSmoother;
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 305 "Gmsh.l"
return tSphere;
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 306 "Gmsh.l"
return tSpline;
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 307 "Gmsh.l"
return tSplit;
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 308 "Gmsh.l"
return tSprintf;
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 309 "Gmsh.l"
return tSqrt;
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 310 "Gmsh.l"
return tStep;
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 311 "Gmsh.l"
return tStr;
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 312 "Gmsh.l"
return tStrCat;
	YY_BREAK
case 237:
YY_RULE_SETUP
#line 313 "Gmsh.l"
return tStrChoice;
	YY_BREAK
case 238:
YY_RULE_SETUP
#line 314 "Gmsh.l"
return tStrCmp;
	YY_BREAK
case 239:
YY_RULE_SETUP
#line 315 "Gmsh.l"
return tStrFind;
	YY_BREAK
case 240:
YY_RULE_SETUP
#line 316 "Gmsh.l"
return tStrLen;
	YY_BREAK
case 241:
YY_RULE_SETUP
#line 317 "Gmsh.l"
return tStrPrefix;
	YY_BREAK
case 242:
YY_RULE_SETUP
#line 318 "Gmsh.l"
return tStrRelative;
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 319 "Gmsh.l"
return tStrReplace;
	YY_BREAK
case 244:
YY_RULE_SETUP
#line 320 "Gmsh.l"
return tStrSub;
	YY_BREAK
case 245:
YY_RULE_SETUP
#line 321 "Gmsh.l"
return tStringToName;
	YY_BREAK
case 246:
YY_RULE_SETUP
#line 322 "Gmsh.l"
return tDefineStruct;
	YY_BREAK
case 247:
YY_RULE_SETUP
#line 323 "Gmsh.l"
return tSurface;
	YY_BREAK
case 248:
YY_RULE_SETUP
#line 324 "Gmsh.l"
return tSymmetry;
	YY_BREAK
case 249:
YY_RULE_SETUP
#line 325 "Gmsh.l"
return tSyncModel;
	YY_BREAK
case 250:
YY_RULE_SETUP
#line 327 "Gmsh.l"
return tText2D;
	YY_BREAK
case 251:
YY_RULE_SETUP
#line 328 "Gmsh.l"
return tText3D;
	YY_BREAK
case 252:
YY_RULE_SETUP
#line 329 "Gmsh.l"
return tTime;
	YY_BREAK
case 253:
YY_RULE_SETUP
#line 330 "Gmsh.l"
return tTan;
	YY_BREAK
case 254:
YY_RULE_SETUP
#line 331 "Gmsh.l"
return tTanh;
	YY_BREAK
case 255:
YY_RULE_SETUP
#line 332 "Gmsh.l"
return tTestLevel;
	YY_BREAK
case 256:
YY_RULE_SETUP
#line 333 "Gmsh.l"
return tTextAttributes;
	YY_BREAK
case 257:
YY_RULE_SETUP
#line 334 "Gmsh.l"
return tThickSolid;
	YY_BREAK
case 258:
YY_RULE_SETUP
#line 335 "Gmsh.l"
return tThruSections;
	YY_BREAK
case 259:
YY_RULE_SETUP
#line 336 "Gmsh.l"
return tToday;
	YY_BREAK
case 260:
YY_RULE_SETUP
#line 337 "Gmsh.l"
return tTorus;
	YY_BREAK
case 261:
YY_RULE_SETUP
#line 338 "Gmsh.l"
return tTotalMemory;
	YY_BREAK
case 262:
YY_RULE_SETUP
#line 339 "Gmsh.l"
return tTransformMesh;
	YY_BREAK
case 263:
YY_RULE_SETUP
#line 340 "Gmsh.l"
return tTransfQuadTri;
	YY_BREAK
case 264:
YY_RULE_SETUP
#line 341 "Gmsh.l"
return tTransfinite;
	YY_BREAK
case 265:
YY_RULE_SETUP
#line 342 "Gmsh.l"
return tTranslate;
	YY_BREAK
case 266:
YY_RULE_SETUP
#line 344 "Gmsh.l"
return tUndefineConstant;
	YY_BREAK
case 267:
YY_RULE_SETUP
#line 345 "Gmsh.l"
return tUnique;
	YY_BREAK
case 268:
YY_RULE_SETUP
#line 346 "Gmsh.l"
return tUnsplitWindow;
	YY_BREAK
case 269:
YY_RULE_SETUP
#line 347 "Gmsh.l"
return tUpperCase;
	YY_BREAK
case 270:
YY_RULE_SETUP
#line 348 "Gmsh.l"
return tUsing;
	YY_BREAK
case 271:
YY_RULE_SETUP
#line 350 "Gmsh.l"
return tVolume;
	YY_BREAK
case 272:
YY_RULE_SETUP
#line 352 "Gmsh.l"
return tWarning;
	YY_BREAK
case 273:
YY_RULE_SETUP
#line 353 "Gmsh.l"
return tWedge;
	YY_BREAK
case 274:
YY_RULE_SETUP
#line 354 "Gmsh.l"
return tWire;
	YY_BREAK
case 275:
#line 357 "Gmsh.l"
case 276:
#line 358 "Gmsh.l"
case 277:
#line 359 "Gmsh.l"
case 278:
YY_RULE_SETUP
#line 359 "Gmsh.l"
{ gmsh_yylval.d = atof((char *)yytext); return tDOUBLE; }
	YY_BREAK
case 279:
YY_RULE_SETUP
#line 361 "Gmsh.l"
{ gmsh_yylval.c = strsave((char*)yytext); return tSTRING; }
	YY_BREAK
case 280:
YY_RULE_SETUP
#line 363 "Gmsh.l"
return yytext[0];
	YY_BREAK
case 281:
YY_RULE_SETUP
#line 365 "Gmsh.l"
ECHO;
	YY_BREAK
#line 3274 "Gmsh.yy.cpp"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((int)((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1462 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1462 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1461);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		yy_size_t number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        yy_size_t yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 365 "Gmsh.l"


#undef gmsh_yywrap

int gmsh_yywrap() { return 1; }

void skipcomments(void)
{
  int c;

  while (1) {
    while ((c = yyinput()) != '*') {
      // Test on YY_END_OF_BUFFER_CHAR (0), not on feof(yyin) because whole line
      // in buffer
      if(c == '\0') {
	Msg::Error("End of file in commented region");
        return;
      }
    }
    if((c = yyinput()) == '/')
      return;
    unput(c);
  }
}

void parsestring(char endchar)
{
  int c;
  char tmp[1024];

  // Note that we keep special characters (end-of-line \n, tabs \t, etc.) "as
  // is" in the output string: see yyinput() above
  int i = 0;
  while ((c = yyinput()) != endchar) {
    // Test on YY_END_OF_BUFFER_CHAR (0), not on feof(yyin) because whole line
    // in buffer
    if(c == '\0') {
      Msg::Error("End of file in string");
      break;
    }
    else if(i >= (int)sizeof(tmp) - 1) {
      Msg::Error("String too long");
      break;
    }
    else{
      tmp[i++] = (char)c;
    }
  }
  tmp[i] = '\0';
  gmsh_yylval.c = strsave(tmp);
}

char *strsave(char *ptr)
{
  return((char*)strcpy((char*)malloc(strlen(ptr) + 1), ptr));
}

void skipline()
{
  int c;
  while ((c = yyinput()) != '\n' && c != '\0') {}
  // TODO: would be clever to skip the current buffer because whole line already
  // in it
}

static bool is_alpha(const int c)
{
  return (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || c == '_';
}

void skip(const char *skip, const char *until)
{
  int i, nb_skip = 0;
  int l_skip, l_until, l_max, l;
  char chars[256];
  int c_next, c_next_skip, c_next_until, c_previous = 0;

  l_skip = skip ? strlen(skip) : 0;
  l_until = strlen(until);

  l_max = std::max(l_skip, l_until);
  if(l_max >= (int)sizeof(chars)) {
    Msg::Error("Search pattern too long in skip");
    return;
  }

  while(1) {
    while(1) {
      chars[0] = yyinput();
      // TOFIX: do another test
      if(feof(yyin)) {
	Msg::Error("Unexpected end of file");
	return;
      }
      if(chars[0] == '/') {
        c_next = yyinput();
        if     (c_next ==  '*') skipcomments();
        else if(c_next ==  '/') skipline();
        else unput(c_next);
      }
      if(chars[0] == '"') {
        parsestring('"');
      }
      if(chars[0] == '\'') {
        parsestring('\'');
      }
      if(!c_previous || !is_alpha(c_previous)) {
        if(chars[0] == until[0]) break;
        if(skip && chars[0] == skip[0]) break;
      }
      c_previous = chars[0];
    }

    l = l_max;

    for(i = 1; i < l; i++) {
      chars[i] = yyinput();
      if(feof(yyin)) {
	l = i;
	break;
      }
    }

    c_next = yyinput(); unput(c_next);
    c_next_skip = (l_skip < l) ? chars[l_skip] : c_next;
    c_next_until = (l_until < l) ? chars[l_until] : c_next;

    if(!strncmp(chars, until, l_until) && !is_alpha(c_next_until)) {
      if(!nb_skip) {
	return;
      }
      else{
	nb_skip--;
      }
    }
    else if(skip && !strncmp(chars, skip, l_skip) && !is_alpha(c_next_skip)) {
      nb_skip++;
      // Attention: unput(.) should be applied a number of times equal to
      // l-l_skip (always >0 for skip="For" and until="EndFor", or skip="If" and
      // until="EndIf"); in particular, because "If" is followed by a minimum of
      // 3 chars (e.g., '(1)'), with a total lenght thus exactly equal to the
      // one of "EndIf", one avoid an error when looking then for
      // "EndIf". (Patrick)
    }
    else{
      for(i = 1; i < l - 1; i++) {
	unput(chars[l - i]);
      }
    }

  }
}

void skipTest(const char *skip, const char *until,
              const char *until2, int l_until2_sub, int *type_until2)
{
  int i, nb_skip = 0;
  int l_skip, l_until, l_until2, l_max, l;
  char chars[256];
  int c_next, c_next_skip, c_next_until, c_next_until2, c_previous = 0;
  int flag_EOL_EOF = 0;

  l_skip = skip ? strlen(skip) : 0;
  l_until = strlen(until);
  l_until2 = until2 ? strlen(until2) : 0;

  l_max = std::max(l_skip, l_until);
  l_max = std::max(l_max, l_until2);
  if(l_max >= (int)sizeof(chars)) {
    Msg::Error("Search pattern too long in skipTest");
    return;
  }

  while(1) {
    while(1) {
      chars[0] = yyinput();
      if(feof(yyin)) {
	Msg::Error("Unexpected end of file");
	return;
      }
      if(chars[0] == '/') {
        c_next = yyinput();
        if     (c_next ==  '*') skipcomments();
        else if(c_next ==  '/') skipline();
        else unput(c_next);
      }
      if(chars[0] == '"'){
        parsestring('"');
      }
      if(chars[0] == '\''){
        parsestring('\'');
      }
      if(!c_previous || !is_alpha(c_previous)) {
        if(chars[0] == until[0]) break;
        if(skip && chars[0] == skip[0]) break;
        if(!nb_skip && until2 && chars[0] == until2[0]) break;
        // Useless to search for until2 if nb_skip!=0
      }
      c_previous = chars[0];
    }

    l = l_max;
    flag_EOL_EOF = 0;

    for(i = 1; i < l; i++) {
      chars[i] = yyinput();
      if(chars[i] == '\n') {
        unput(chars[i]); chars[i] = 0; l = i; flag_EOL_EOF = 1;
        break;
      }
      if(feof(yyin)) {
	l = i; flag_EOL_EOF = 1;
	break;
      }
    }

    if(!flag_EOL_EOF) {
      c_next = yyinput(); unput(c_next);
      c_next_skip = (l_skip < l) ? chars[l_skip] : c_next;
      c_next_until = (l_until < l) ? chars[l_until] : c_next;
      if(!nb_skip)
        c_next_until2 = (l_until2 < l) ? chars[l_until2] : c_next;
    }
    else{
      c_next = 0; c_next_skip = 0; c_next_until = 0; c_next_until2 = 0;
    }

    if(!nb_skip && !strncmp(chars, until2, l_until2) &&
       !is_alpha(c_next_until2)) {
      *type_until2 = 1; // Found word is full until2 (e.g., "ElseIf")
      for(int i = 1; i <= l; i++) { // Only correct if l == l_until2
        unput(chars[l - i]);
      } // New file position points "ElseIf", that will be then analysed by the parser
      return;
    }
    else if(!nb_skip && !strncmp(chars,until2,l_until2_sub) &&
            !is_alpha(chars[l_until2_sub])) {
      *type_until2 = 2; // Found word is subword from until2 (e.g., "Else")
      for(int i = 1; i <= l - l_until2_sub; i++) { // Only correct if l_until2_sub < l
        unput(chars[l - i]);
      }
      return;
    }
    else if(!strncmp(chars, until, l_until) && !is_alpha(c_next_until)) {
      for(int i = 1; i <= l - l_until; i++) {
        unput(chars[l - i]);
      }
      if(!nb_skip) {
	return;
      }
      else{
	nb_skip--;
      }
    }
    else if(skip && !strncmp(chars, skip, l_skip) && !is_alpha(c_next_skip)) {
      nb_skip++;
    }
    else{
      for(i = 1; i < l - 1; i++) {
	unput(chars[l - i]);
      }
    }

  }
}

void gmsh_yyflush() { YY_FLUSH_BUFFER; }

